@@ -15,9 +15,9 @@ class FolderType(Enum):
 
 
 class RootFolder(DeeplabelBase):
-    type: Optional[FolderType]
     folder_id: Optional[str]
     project_id: str
+    type: FolderType = FolderType.VIDEO
 
     @property
     def folders(self):
@@ -56,6 +56,7 @@ class RootFolder(DeeplabelBase):
 
 
 class Folder(RootFolder):
+    folder_id: str
     description: str
     name: str
     parent_folder_id: Optional[str]
